"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/** @jsx jsx */
const react_1 = __importDefault(require("react"));
const core_1 = require("@emotion/core");
const sdk_1 = require("@builder.io/sdk");
const core_2 = require("@material-ui/core");
const CloudinaryMediaLibraryDialog_1 = require("./CloudinaryMediaLibraryDialog");
const CloudinaryCredentialsDialog_1 = __importDefault(require("./CloudinaryCredentialsDialog"));
class CloudinaryImageEditor extends react_1.default.Component {
    get organization() {
        return this.props.context.user.organization;
    }
    get cloudinaryCloud() {
        return this.organization.value.settings.plugins.get('cloudinaryCloud');
    }
    set cloudinaryCloud(cloud) {
        this.organization.value.settings.plugins.set('cloudinaryCloud', cloud);
        this.organization.save();
    }
    get cloudinaryKey() {
        return this.organization.value.settings.plugins.get('cloudinaryKey');
    }
    set cloudinaryKey(key) {
        this.organization.value.settings.plugins.set('cloudinaryKey', key);
        this.organization.save();
    }
    constructor(props) {
        super(props);
        this.state = {
            requestCredentials: false,
            showDialog: false,
            apiKey: this.cloudinaryKey ? this.cloudinaryKey : '',
            cloudName: this.cloudinaryCloud ? this.cloudinaryCloud : '',
            selectedImagePublicId: props.value && props.value.get && props.value.get('public_id')
                ? props.value.get('public_id')
                : '',
        };
    }
    closeDialog() {
        this.setState({
            requestCredentials: false,
            showDialog: false,
        });
    }
    appendMediaLibraryScriptToPlugin() {
        const previousScript = document.getElementById('cloudinaryScript');
        if (!previousScript) {
            const script = document.createElement('script');
            script.async = true;
            script.src = `https://media-library.cloudinary.com/global/all.js`;
            script.id = 'cloudinaryScript';
            document.head.appendChild(script);
        }
    }
    areCloudinaryCredentialsNotSet() {
        return (this.state.apiKey === '' ||
            this.state.cloudName === '' ||
            this.state.apiKey === undefined ||
            this.state.cloudName === undefined);
    }
    shouldRequestCloudinaryCredentials() {
        return this.state.requestCredentials || this.areCloudinaryCredentialsNotSet();
    }
    updateCloudinaryCredentials(apiKey, cloudName) {
        this.cloudinaryKey = apiKey;
        this.cloudinaryCloud = cloudName;
        this.setState({
            apiKey: this.cloudinaryKey,
            cloudName: this.cloudinaryCloud,
        });
    }
    calculateChooseImageButtonVariant() {
        return this.areCloudinaryCredentialsNotSet() ? 'contained' : 'text';
    }
    selectImage(image) {
        this.props.onChange(image);
        this.setState({ selectedImagePublicId: image.public_id });
    }
    buildSelectedIdMessage() {
        if (this.state.selectedImagePublicId) {
            return `Public id: ${this.state.selectedImagePublicId}`;
        }
        return 'Please choose an image';
    }
    buildChooseImageText() {
        if (this.state.selectedImagePublicId) {
            return `UPDATE IMAGE`;
        }
        return 'CHOOSE IMAGE';
    }
    componentDidMount() {
        this.appendMediaLibraryScriptToPlugin();
    }
    render() {
        const shouldRequestCloudinarySettings = this.shouldRequestCloudinaryCredentials();
        const setCredentialsButtonVariant = this.calculateChooseImageButtonVariant();
        const selectedPublicIdMessage = this.buildSelectedIdMessage();
        const chooseImageButtonText = this.buildChooseImageText();
        const buttonStyle = { width: '45%', margin: '5px' };
        return (core_1.jsx("div", { css: { padding: '15px 0' } },
            core_1.jsx(core_2.Typography, { variant: "caption" }, "Cloudinary image picker"),
            shouldRequestCloudinarySettings && (core_1.jsx(CloudinaryCredentialsDialog_1.default, { openDialog: this.state.showDialog, closeDialog: this.closeDialog.bind(this), updateCloudinaryCredentials: this.updateCloudinaryCredentials.bind(this), apiKey: this.state.apiKey, cloudName: this.state.cloudName })),
            !shouldRequestCloudinarySettings && (core_1.jsx(CloudinaryMediaLibraryDialog_1.CloudinaryMediaLibraryDialog, { openDialog: this.state.showDialog, closeDialog: this.closeDialog.bind(this), selectImage: this.selectImage.bind(this), apiKey: this.state.apiKey, cloudName: this.state.cloudName })),
            core_1.jsx("div", null,
                core_1.jsx(core_2.Button, { disabled: this.areCloudinaryCredentialsNotSet(), css: buttonStyle, color: "primary", variant: "contained", onClick: () => {
                        this.setState({
                            showDialog: !this.state.showDialog,
                        });
                    } }, chooseImageButtonText),
                core_1.jsx(core_2.Button, { variant: setCredentialsButtonVariant, color: "primary", css: buttonStyle, onClick: () => {
                        this.setState({
                            requestCredentials: true,
                            showDialog: !this.state.showDialog,
                        });
                    } }, "Set credentials")),
            core_1.jsx("div", null,
                core_1.jsx(core_2.Typography, { css: { margin: '5px' }, variant: "caption" }, selectedPublicIdMessage))));
    }
}
exports.default = CloudinaryImageEditor;
sdk_1.Builder.registerEditor({
    name: 'cloudinaryImageEditor',
    component: CloudinaryImageEditor,
});
//# sourceMappingURL=CloudinaryImageEditor.js.map